<?php

namespace Icinga\Module\Director\Clicommands;

use Icinga\Module\Director\Cli\ObjectCommand;

/**
 * Manage Icinga Commands
 *
 * Use this command to show, create, modify or delete Icinga Command
 * objects
 */
class CommandCommand extends ObjectCommand
{
}
